# quicat

**qui**ck **C**lonal **A**nalysis **T**oolkit—`quiCAT`—is a toolkit for extracting, and analyzing clonal populations from sequencing data. Designed for flexibility and performance, it simplifies the process genetic barcodes extraction from bulkDNA, single-cell, and spatial transcriptomics datasets.

---

Install with

```bash
pip install quicat
```

- **Documentation** <https://theislab.github.io/quicat/>
